package cn.estsh.i3plus.ext.mes.apiservice.serviceimpl.base;

import cn.estsh.i3plus.ext.mes.api.base.IMesCustomerRoadService;
import cn.estsh.i3plus.ext.mes.api.base.IMesCustomerService;
import cn.estsh.i3plus.platform.common.exception.ImppExceptionEnum;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.MesCustomer;
import cn.estsh.i3plus.pojo.mes.bean.MesCustomerRoad;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

/**
 * @author yinxiao
 * @date 2023-2023/6/2 10:54
 * @Description
 */
@Service
@Slf4j
public class MesCustomerService extends BaseMesService<MesCustomer> implements IMesCustomerService {



    protected void onInsertBean(MesCustomer item) {
        // 数据校验
        ValidatorBean.checkNotNull(item.getCustomerCode(), "客户代码不能为空");

        DdlPackBean roadPackBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getCustomerCode(), "customerCode", roadPackBean);
        boolean flg = baseRDao.isExitByHql(roadPackBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】客户代码已经存在，请检查数据", item.getCustomerCode())
                    .build();
        }

    }

    protected void onUpdateBean(MesCustomerRoad item) {
        // 数据校验
        ValidatorBean.checkNotNull(item.getCustomerCode(), "客户代码不能为空");

        DdlPackBean roadPackBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getCustomerCode(), "customerCode", roadPackBean);
        DdlPreparedPack.getNumNOEqualPack(item.getId(), "id", roadPackBean);
        boolean flg = baseRDao.isExitByHql(roadPackBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】客户代码已经存在，请检查数据", item.getCustomerCode(), item.getRoadCode())
                    .build();
        }
    }

    protected void setPackQueryBean(MesCustomer bean, DdlPackBean packBean) {
        DdlPreparedPack.getStringEqualPack(bean.getCustomerCode(), "customerCode", packBean);
        DdlPreparedPack.getStringLikerPack(bean.getCustomerName(), "customerName", packBean);
    }

}
